// diffView.cpp : implementation of the CDiffView class
//

#include "stdafx.h"
#include "diff.h"

#include "diffDoc.h"
#include "diffView.h"
#include "progress.h"
#include "splitter.h"
#include "FindDiff.h"
#include "mainfrm.h"
#include "resource.h"
#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CDiffView

IMPLEMENT_DYNCREATE(CDiffView, CRichEditView)

BEGIN_MESSAGE_MAP(CDiffView, CRichEditView)
	ON_WM_CONTEXTMENU()
	//{{AFX_MSG_MAP(CDiffView)
	ON_WM_DROPFILES()
	ON_WM_RBUTTONUP()
	ON_COMMAND(ID_EDIT_FONT, OnEditFont)
	ON_COMMAND(IDC_EDIT_COLOR_BACKGROUND, OnEditColorBackground)
	ON_COMMAND(IDC_EDIT_COLOR_FOREGROUND, OnEditColorForeground)
	//}}AFX_MSG_MAP
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, CRichEditView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_DIRECT, CRichEditView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_PREVIEW, CRichEditView::OnFilePrintPreview)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CDiffView construction/destruction

CDiffView::CDiffView()
{
	m_BackgroundColor = RGB(255, 255, 255);  // white
	m_ForegroundColor = RGB(0, 0, 255);			//black
}

CDiffView::~CDiffView()
{
}

BOOL CDiffView::PreCreateWindow(CREATESTRUCT& cs)
{
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	return CRichEditView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CDiffView drawing

void CDiffView::OnDraw(CDC* pDC)
{
	CDiffDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);

	// TODO: add draw code for native data here
}

/////////////////////////////////////////////////////////////////////////////
// CDiffView printing

BOOL CDiffView::OnPreparePrinting(CPrintInfo* pInfo)
{
	// default preparation
	return DoPreparePrinting(pInfo);
}

void CDiffView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add extra initialization before printing
}

void CDiffView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add cleanup after printing
}

/////////////////////////////////////////////////////////////////////////////
// CDiffView diagnostics

#ifdef _DEBUG
void CDiffView::AssertValid() const
{
	CRichEditView::AssertValid();
}

void CDiffView::Dump(CDumpContext& dc) const
{
	CRichEditView::Dump(dc);
}

CDiffDoc* CDiffView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CDiffDoc)));
	return (CDiffDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CDiffView message handlers

void CDiffView::OnInitialUpdate() 
{
	CRichEditView::OnInitialUpdate();
	GetRichEditCtrl().SetReadOnly();
}

void CDiffView::OnDropFiles(HDROP hDropInfo) 
{
	CDiffApp::GetApp()->GetMainFrame()->
		SendMessage ( WM_DROPFILES,
					  (WPARAM)hDropInfo);
	//Don't call the default -- we don't want OLE
	//embedding behavior
	//CRichEditView::OnDropFiles(hDropInfo);
}

void CDiffView::OnContextMenu(CWnd *pWnd, CPoint point)
{
	UNUSED_ALWAYS (pWnd);	CMenu menu;
	VERIFY(menu.LoadMenu(IDR_POPUP_DIFF_VIEW));

	CMenu* pPopup = menu.GetSubMenu(0);
	ASSERT(pPopup != NULL);

	if (pPopup != NULL)
		pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_RIGHTBUTTON, 
								point.x, point.y, this);
}

void CDiffView::OnRButtonUp(UINT nFlags, CPoint point) 
{
	//CRichEditView::OnRButtonUp(nFlags, point);
	ClientToScreen (&point);
	OnContextMenu ((CWnd *)NULL, point);
}

void CDiffView::OnEditFont() 
{
	GetRichEditCtrl().GetDefaultCharFormat(m_CharacterFormat);

	CFontDialog dlg(m_CharacterFormat,CF_SCREENFONTS);

	if (dlg.DoModal() == IDOK)
	{
		dlg.GetCharFormat(m_CharacterFormat);
		GetRichEditCtrl().SetDefaultCharFormat(m_CharacterFormat);
	}
}

void CDiffView::OnEditColorBackground() 
{
	CColorDialog dlg(m_BackgroundColor);

	if (dlg.DoModal() == IDOK)
	{
		m_BackgroundColor = dlg.GetColor();
		GetRichEditCtrl().SetBackgroundColor(FALSE, m_BackgroundColor);
	}
}

void CDiffView::OnEditColorForeground() 
{
	GetRichEditCtrl().GetDefaultCharFormat(m_CharacterFormat);
	m_CharacterFormat.crTextColor = m_ForegroundColor;
	CColorDialog dlg(m_CharacterFormat.crTextColor);

	if (dlg.DoModal() == IDOK)
	{
		m_CharacterFormat.crTextColor = dlg.GetColor();
		m_ForegroundColor = m_CharacterFormat.crTextColor;
		m_CharacterFormat.dwEffects = 0;
		m_CharacterFormat.dwMask = CFM_COLOR;
		GetRichEditCtrl().SetDefaultCharFormat(m_CharacterFormat);
	}
}
